@@ -444,10 +444,9 @@ wifi_new_auto_connection (NMDevice *device,
 	NMConnection *connection;
 	NMSettingConnection *s_con;
 	NMSettingWireless *s_wifi = NULL;
-	NMSettingWirelessSecurity *s_wsec = NULL;
+	NMSettingWirelessSecurity *s_wsec;
 	NMSetting8021x *s_8021x = NULL;
 	GBytes *ssid;
-	NM80211ApFlags flags;
 	NM80211ApSecurityFlags wpa_flags, rsn_flags;
 	GtkWidget *dialog;
 	MoreInfo *more_info;
@@ -463,10 +462,15 @@ wifi_new_auto_connection (NMDevice *device,
 
 	connection = nm_simple_connection_new ();
 
-	/* Make the new connection available only for the current user */
 	s_con = (NMSettingConnection *) nm_setting_connection_new ();
 	nm_connection_add_setting (connection, NM_SETTING (s_con));
 
+	if (applet->permissions[NM_CLIENT_PERMISSION_SETTINGS_MODIFY_SYSTEM]
+	    != NM_CLIENT_PERMISSION_RESULT_YES) {
+		/* Make the new connection available only for the current user */
+		nm_setting_connection_add_permission (s_con, "user", g_get_user_name (), NULL);
+	}
+
 	ssid = nm_access_point_get_ssid (ap);
 	if (   (nm_access_point_get_mode (ap) == NM_802_11_MODE_INFRA)
 	    && (is_manufacturer_default_ssid (ssid) == TRUE)) {
@@ -482,7 +486,6 @@ wifi_new_auto_connection (NMDevice *device,
 	/* If the AP is WPA[2]-Enterprise then we need to set up a minimal 802.1x
 	 * setting and ask the user for more information.
 	 */
-	flags = nm_access_point_get_flags (ap);
 	rsn_flags = nm_access_point_get_rsn_flags (ap);
 	wpa_flags = nm_access_point_get_wpa_flags (ap);
 	if (   (rsn_flags & NM_802_11_AP_SEC_KEY_MGMT_802_1X)
@@ -511,29 +514,6 @@ wifi_new_auto_connection (NMDevice *device,
 		nm_connection_add_setting (connection, NM_SETTING (s_8021x));
 	}
 
-	if (utils_default_to_private_connection (applet->nm_client)) {
-		if (!s_con) {
-			s_con = (NMSettingConnection *) nm_setting_connection_new ();
-			nm_connection_add_setting (connection, NM_SETTING (s_con));
-		}
-		nm_setting_connection_add_permission (s_con, "user", g_get_user_name (), NULL);
-
-		if ((rsn_flags & NM_802_11_AP_SEC_KEY_MGMT_PSK) ||
-		    (wpa_flags & NM_802_11_AP_SEC_KEY_MGMT_PSK)) {
-			if (!s_wsec) {
-				s_wsec = (NMSettingWirelessSecurity *) nm_setting_wireless_security_new ();
-				nm_connection_add_setting (connection, NM_SETTING (s_wsec));
-			}
-			g_object_set (s_wsec, NM_SETTING_WIRELESS_SECURITY_PSK_FLAGS, NM_SETTING_SECRET_FLAG_AGENT_OWNED, NULL);
-		} else if (flags & NM_802_11_AP_FLAGS_PRIVACY) {
-			if (!s_wsec) {
-				s_wsec = (NMSettingWirelessSecurity *) nm_setting_wireless_security_new ();
-				nm_connection_add_setting (connection, NM_SETTING (s_wsec));
-			}
-			g_object_set (s_wsec, NM_SETTING_WIRELESS_SECURITY_WEP_KEY_FLAGS, NM_SETTING_SECRET_FLAG_AGENT_OWNED, NULL);
-		}
-	}
-
 	/* If it's an 802.1x connection, we need more information, so pop up the
 	 * Dialog Of Doom.
 	 */
@@ -815,7 +795,7 @@ sort_toplevel (gconstpointer tmpa, gconstpointer tmpb)
 	return sort_by_name (a, b);
 }
 
-static void
+static gboolean
 wifi_add_menu_item (NMDevice *device,
                     gboolean multiple_devices,
                     const GPtrArray *connections,
@@ -958,6 +938,7 @@ wifi_add_menu_item (NMDevice *device,
 
 out:
 	g_slist_free (menu_items);
+	return TRUE;
 }
 
 static void
